==> servicecatalog-model-6.9.1-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBrokerSpecFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ServiceBrokerSpecFluent<A extends ServiceBrokerSpecFluent<A>> extends BaseFluent<A>{
  public ServiceBrokerSpecFluent() {
  }
  
  public ServiceBrokerSpecFluent(ServiceBrokerSpec instance) {
    this.copyInstance(instance);
  }
  private ServiceBrokerAuthInfoBuilder authInfo;
  private String caBundle;
  private CatalogRestrictionsBuilder catalogRestrictions;
  private Boolean insecureSkipTLSVerify;
  private String relistBehavior;
  private Duration relistDuration;
  private Long relistRequests;
  private String url;
  
  protected void copyInstance(ServiceBrokerSpec instance) {
    instance = (instance != null ? instance : new ServiceBrokerSpec());
    if (instance != null) {
          this.withAuthInfo(instance.getAuthInfo());
          this.withCaBundle(instance.getCaBundle());
          this.withCatalogRestrictions(instance.getCatalogRestrictions());
          this.withInsecureSkipTLSVerify(instance.getInsecureSkipTLSVerify());
          this.withRelistBehavior(instance.getRelistBehavior());
          this.withRelistDuration(instance.getRelistDuration());
          this.withRelistRequests(instance.getRelistRequests());
          this.withUrl(instance.getUrl());
          this.withAuthInfo(instance.getAuthInfo());
          this.withCaBundle(instance.getCaBundle());
          this.withCatalogRestrictions(instance.getCatalogRestrictions());
          this.withInsecureSkipTLSVerify(instance.getInsecureSkipTLSVerify());
          this.withRelistBehavior(instance.getRelistBehavior());
          this.withRelistDuration(instance.getRelistDuration());
          this.withRelistRequests(instance.getRelistRequests());
          this.withUrl(instance.getUrl());
        }
  }
  
  public ServiceBrokerAuthInfo buildAuthInfo() {
    return this.authInfo != null ? this.authInfo.build() : null;
  }
  
  public A withAuthInfo(ServiceBrokerAuthInfo authInfo) {
    this._visitables.remove(this.authInfo);
    if (authInfo != null) {
        this.authInfo = new ServiceBrokerAuthInfoBuilder(authInfo);
        this._visitables.get("authInfo").add(this.authInfo);
    } else {
        this.authInfo = null;
        this._visitables.get("authInfo").remove(this.authInfo);
    }
    return (A) this;
  }
  
  public boolean hasAuthInfo() {
    return this.authInfo != null;
  }
  
  public AuthInfoNested<A> withNewAuthInfo() {
    return new AuthInfoNested(null);
  }
  
  public AuthInfoNested<A> withNewAuthInfoLike(ServiceBrokerAuthInfo item) {
    return new AuthInfoNested(item);
  }
  
  public AuthInfoNested<A> editAuthInfo() {
    return withNewAuthInfoLike(java.util.Optional.ofNullable(buildAuthInfo()).orElse(null));
  }
  
  public AuthInfoNested<A> editOrNewAuthInfo() {
    return withNewAuthInfoLike(java.util.Optional.ofNullable(buildAuthInfo()).orElse(new ServiceBrokerAuthInfoBuilder().build()));
  }
  
  public AuthInfoNested<A> editOrNewAuthInfoLike(ServiceBrokerAuthInfo item) {
    return withNewAuthInfoLike(java.util.Optional.ofNullable(buildAuthInfo()).orElse(item));
  }
  
  public String getCaBundle() {
    return this.caBundle;
  }
  
  public A withCaBundle(String caBundle) {
    this.caBundle = caBundle;
    return (A) this;
  }
  
  public boolean hasCaBundle() {
    return this.caBundle != null;
  }
  
  public CatalogRestrictions buildCatalogRestrictions() {
    return this.catalogRestrictions != null ? this.catalogRestrictions.build() : null;
  }
  
  public A withCatalogRestrictions(CatalogRestrictions catalogRestrictions) {
    this._visitables.remove(this.catalogRestrictions);
    if (catalogRestrictions != null) {
        this.catalogRestrictions = new CatalogRestrictionsBuilder(catalogRestrictions);
        this._visitables.get("catalogRestrictions").add(this.catalogRestrictions);
    } else {
        this.catalogRestrictions = null;
        this._visitables.get("catalogRestrictions").remove(this.catalogRestrictions);
    }
    return (A) this;
  }
  
  public boolean hasCatalogRestrictions() {
    return this.catalogRestrictions != null;
  }
  
  public CatalogRestrictionsNested<A> withNewCatalogRestrictions() {
    return new CatalogRestrictionsNested(null);
  }
  
  public CatalogRestrictionsNested<A> withNewCatalogRestrictionsLike(CatalogRestrictions item) {
    return new CatalogRestrictionsNested(item);
  }
  
  public CatalogRestrictionsNested<A> editCatalogRestrictions() {
    return withNewCatalogRestrictionsLike(java.util.Optional.ofNullable(buildCatalogRestrictions()).orElse(null));
  }
  
  public CatalogRestrictionsNested<A> editOrNewCatalogRestrictions() {
    return withNewCatalogRestrictionsLike(java.util.Optional.ofNullable(buildCatalogRestrictions()).orElse(new CatalogRestrictionsBuilder().build()));
  }
  
  public CatalogRestrictionsNested<A> editOrNewCatalogRestrictionsLike(CatalogRestrictions item) {
    return withNewCatalogRestrictionsLike(java.util.Optional.ofNullable(buildCatalogRestrictions()).orElse(item));
  }
  
  public Boolean getInsecureSkipTLSVerify() {
    return this.insecureSkipTLSVerify;
  }
  
  public A withInsecureSkipTLSVerify(Boolean insecureSkipTLSVerify) {
    this.insecureSkipTLSVerify = insecureSkipTLSVerify;
    return (A) this;
  }
  
  public boolean hasInsecureSkipTLSVerify() {
    return this.insecureSkipTLSVerify != null;
  }
  
  public String getRelistBehavior() {
    return this.relistBehavior;
  }
  
  public A withRelistBehavior(String relistBehavior) {
    this.relistBehavior = relistBehavior;
    return (A) this;
  }
  
  public boolean hasRelistBehavior() {
    return this.relistBehavior != null;
  }
  
  public Duration getRelistDuration() {
    return this.relistDuration;
  }
  
  public A withRelistDuration(Duration relistDuration) {
    this.relistDuration = relistDuration;
    return (A) this;
  }
  
  public boolean hasRelistDuration() {
    return this.relistDuration != null;
  }
  
  public Long getRelistRequests() {
    return this.relistRequests;
  }
  
  public A withRelistRequests(Long relistRequests) {
    this.relistRequests = relistRequests;
    return (A) this;
  }
  
  public boolean hasRelistRequests() {
    return this.relistRequests != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url = url;
    return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceBrokerSpecFluent that = (ServiceBrokerSpecFluent) o;
    if (!java.util.Objects.equals(authInfo, that.authInfo)) return false;
    if (!java.util.Objects.equals(caBundle, that.caBundle)) return false;
    if (!java.util.Objects.equals(catalogRestrictions, that.catalogRestrictions)) return false;
    if (!java.util.Objects.equals(insecureSkipTLSVerify, that.insecureSkipTLSVerify)) return false;
    if (!java.util.Objects.equals(relistBehavior, that.relistBehavior)) return false;
    if (!java.util.Objects.equals(relistDuration, that.relistDuration)) return false;
    if (!java.util.Objects.equals(relistRequests, that.relistRequests)) return false;
    if (!java.util.Objects.equals(url, that.url)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(authInfo,  caBundle,  catalogRestrictions,  insecureSkipTLSVerify,  relistBehavior,  relistDuration,  relistRequests,  url,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authInfo != null) { sb.append("authInfo:"); sb.append(authInfo + ","); }
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (catalogRestrictions != null) { sb.append("catalogRestrictions:"); sb.append(catalogRestrictions + ","); }
    if (insecureSkipTLSVerify != null) { sb.append("insecureSkipTLSVerify:"); sb.append(insecureSkipTLSVerify + ","); }
    if (relistBehavior != null) { sb.append("relistBehavior:"); sb.append(relistBehavior + ","); }
    if (relistDuration != null) { sb.append("relistDuration:"); sb.append(relistDuration + ","); }
    if (relistRequests != null) { sb.append("relistRequests:"); sb.append(relistRequests + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withInsecureSkipTLSVerify() {
    return withInsecureSkipTLSVerify(true);
  }
  public class AuthInfoNested<N> extends ServiceBrokerAuthInfoFluent<AuthInfoNested<N>> implements Nested<N>{
    AuthInfoNested(ServiceBrokerAuthInfo item) {
      this.builder = new ServiceBrokerAuthInfoBuilder(this, item);
    }
    ServiceBrokerAuthInfoBuilder builder;
    
    public N and() {
      return (N) ServiceBrokerSpecFluent.this.withAuthInfo(builder.build());
    }
    
    public N endAuthInfo() {
      return and();
    }
    
  
  }
  public class CatalogRestrictionsNested<N> extends CatalogRestrictionsFluent<CatalogRestrictionsNested<N>> implements Nested<N>{
    CatalogRestrictionsNested(CatalogRestrictions item) {
      this.builder = new CatalogRestrictionsBuilder(this, item);
    }
    CatalogRestrictionsBuilder builder;
    
    public N and() {
      return (N) ServiceBrokerSpecFluent.this.withCatalogRestrictions(builder.build());
    }
    
    public N endCatalogRestrictions() {
      return and();
    }
    
  
  }

}

==> servicecatalog-model-6.9.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBrokerSpecFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ServiceBrokerSpecFluent<A extends ServiceBrokerSpecFluent<A>> extends BaseFluent<A>{
  public ServiceBrokerSpecFluent() {
  }
  
  public ServiceBrokerSpecFluent(ServiceBrokerSpec instance) {
    this.copyInstance(instance);
  }
  private ServiceBrokerAuthInfoBuilder authInfo;
  private String caBundle;
  private CatalogRestrictionsBuilder catalogRestrictions;
  private Boolean insecureSkipTLSVerify;
  private String relistBehavior;
  private Duration relistDuration;
  private Long relistRequests;
  private String url;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ServiceBrokerSpec instance) {
    instance = (instance != null ? instance : new ServiceBrokerSpec());
    if (instance != null) {
          this.withAuthInfo(instance.getAuthInfo());
          this.withCaBundle(instance.getCaBundle());
          this.withCatalogRestrictions(instance.getCatalogRestrictions());
          this.withInsecureSkipTLSVerify(instance.getInsecureSkipTLSVerify());
          this.withRelistBehavior(instance.getRelistBehavior());
          this.withRelistDuration(instance.getRelistDuration());
          this.withRelistRequests(instance.getRelistRequests());
          this.withUrl(instance.getUrl());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ServiceBrokerAuthInfo buildAuthInfo() {
    return this.authInfo != null ? this.authInfo.build() : null;
  }
  
  public A withAuthInfo(ServiceBrokerAuthInfo authInfo) {
    this._visitables.remove("authInfo");
    if (authInfo != null) {
        this.authInfo = new ServiceBrokerAuthInfoBuilder(authInfo);
        this._visitables.get("authInfo").add(this.authInfo);
    } else {
        this.authInfo = null;
        this._visitables.get("authInfo").remove(this.authInfo);
    }
    return (A) this;
  }
  
  public boolean hasAuthInfo() {
    return this.authInfo != null;
  }
  
  public AuthInfoNested<A> withNewAuthInfo() {
    return new AuthInfoNested(null);
  }
  
  public AuthInfoNested<A> withNewAuthInfoLike(ServiceBrokerAuthInfo item) {
    return new AuthInfoNested(item);
  }
  
  public AuthInfoNested<A> editAuthInfo() {
    return withNewAuthInfoLike(java.util.Optional.ofNullable(buildAuthInfo()).orElse(null));
  }
  
  public AuthInfoNested<A> editOrNewAuthInfo() {
    return withNewAuthInfoLike(java.util.Optional.ofNullable(buildAuthInfo()).orElse(new ServiceBrokerAuthInfoBuilder().build()));
  }
  
  public AuthInfoNested<A> editOrNewAuthInfoLike(ServiceBrokerAuthInfo item) {
    return withNewAuthInfoLike(java.util.Optional.ofNullable(buildAuthInfo()).orElse(item));
  }
  
  public String getCaBundle() {
    return this.caBundle;
  }
  
  public A withCaBundle(String caBundle) {
    this.caBundle = caBundle;
    return (A) this;
  }
  
  public boolean hasCaBundle() {
    return this.caBundle != null;
  }
  
  public CatalogRestrictions buildCatalogRestrictions() {
    return this.catalogRestrictions != null ? this.catalogRestrictions.build() : null;
  }
  
  public A withCatalogRestrictions(CatalogRestrictions catalogRestrictions) {
    this._visitables.remove("catalogRestrictions");
    if (catalogRestrictions != null) {
        this.catalogRestrictions = new CatalogRestrictionsBuilder(catalogRestrictions);
        this._visitables.get("catalogRestrictions").add(this.catalogRestrictions);
    } else {
        this.catalogRestrictions = null;
        this._visitables.get("catalogRestrictions").remove(this.catalogRestrictions);
    }
    return (A) this;
  }
  
  public boolean hasCatalogRestrictions() {
    return this.catalogRestrictions != null;
  }
  
  public CatalogRestrictionsNested<A> withNewCatalogRestrictions() {
    return new CatalogRestrictionsNested(null);
  }
  
  public CatalogRestrictionsNested<A> withNewCatalogRestrictionsLike(CatalogRestrictions item) {
    return new CatalogRestrictionsNested(item);
  }
  
  public CatalogRestrictionsNested<A> editCatalogRestrictions() {
    return withNewCatalogRestrictionsLike(java.util.Optional.ofNullable(buildCatalogRestrictions()).orElse(null));
  }
  
  public CatalogRestrictionsNested<A> editOrNewCatalogRestrictions() {
    return withNewCatalogRestrictionsLike(java.util.Optional.ofNullable(buildCatalogRestrictions()).orElse(new CatalogRestrictionsBuilder().build()));
  }
  
  public CatalogRestrictionsNested<A> editOrNewCatalogRestrictionsLike(CatalogRestrictions item) {
    return withNewCatalogRestrictionsLike(java.util.Optional.ofNullable(buildCatalogRestrictions()).orElse(item));
  }
  
  public Boolean getInsecureSkipTLSVerify() {
    return this.insecureSkipTLSVerify;
  }
  
  public A withInsecureSkipTLSVerify(Boolean insecureSkipTLSVerify) {
    this.insecureSkipTLSVerify = insecureSkipTLSVerify;
    return (A) this;
  }
  
  public boolean hasInsecureSkipTLSVerify() {
    return this.insecureSkipTLSVerify != null;
  }
  
  public String getRelistBehavior() {
    return this.relistBehavior;
  }
  
  public A withRelistBehavior(String relistBehavior) {
    this.relistBehavior = relistBehavior;
    return (A) this;
  }
  
  public boolean hasRelistBehavior() {
    return this.relistBehavior != null;
  }
  
  public Duration getRelistDuration() {
    return this.relistDuration;
  }
  
  public A withRelistDuration(Duration relistDuration) {
    this.relistDuration = relistDuration;
    return (A) this;
  }
  
  public boolean hasRelistDuration() {
    return this.relistDuration != null;
  }
  
  public Long getRelistRequests() {
    return this.relistRequests;
  }
  
  public A withRelistRequests(Long relistRequests) {
    this.relistRequests = relistRequests;
    return (A) this;
  }
  
  public boolean hasRelistRequests() {
    return this.relistRequests != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url = url;
    return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceBrokerSpecFluent that = (ServiceBrokerSpecFluent) o;
    if (!java.util.Objects.equals(authInfo, that.authInfo)) return false;
    if (!java.util.Objects.equals(caBundle, that.caBundle)) return false;
    if (!java.util.Objects.equals(catalogRestrictions, that.catalogRestrictions)) return false;
    if (!java.util.Objects.equals(insecureSkipTLSVerify, that.insecureSkipTLSVerify)) return false;
    if (!java.util.Objects.equals(relistBehavior, that.relistBehavior)) return false;
    if (!java.util.Objects.equals(relistDuration, that.relistDuration)) return false;
    if (!java.util.Objects.equals(relistRequests, that.relistRequests)) return false;
    if (!java.util.Objects.equals(url, that.url)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(authInfo,  caBundle,  catalogRestrictions,  insecureSkipTLSVerify,  relistBehavior,  relistDuration,  relistRequests,  url,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authInfo != null) { sb.append("authInfo:"); sb.append(authInfo + ","); }
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (catalogRestrictions != null) { sb.append("catalogRestrictions:"); sb.append(catalogRestrictions + ","); }
    if (insecureSkipTLSVerify != null) { sb.append("insecureSkipTLSVerify:"); sb.append(insecureSkipTLSVerify + ","); }
    if (relistBehavior != null) { sb.append("relistBehavior:"); sb.append(relistBehavior + ","); }
    if (relistDuration != null) { sb.append("relistDuration:"); sb.append(relistDuration + ","); }
    if (relistRequests != null) { sb.append("relistRequests:"); sb.append(relistRequests + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withInsecureSkipTLSVerify() {
    return withInsecureSkipTLSVerify(true);
  }
  public class AuthInfoNested<N> extends ServiceBrokerAuthInfoFluent<AuthInfoNested<N>> implements Nested<N>{
    AuthInfoNested(ServiceBrokerAuthInfo item) {
      this.builder = new ServiceBrokerAuthInfoBuilder(this, item);
    }
    ServiceBrokerAuthInfoBuilder builder;
    
    public N and() {
      return (N) ServiceBrokerSpecFluent.this.withAuthInfo(builder.build());
    }
    
    public N endAuthInfo() {
      return and();
    }
    
  
  }
  public class CatalogRestrictionsNested<N> extends CatalogRestrictionsFluent<CatalogRestrictionsNested<N>> implements Nested<N>{
    CatalogRestrictionsNested(CatalogRestrictions item) {
      this.builder = new CatalogRestrictionsBuilder(this, item);
    }
    CatalogRestrictionsBuilder builder;
    
    public N and() {
      return (N) ServiceBrokerSpecFluent.this.withCatalogRestrictions(builder.build());
    }
    
    public N endCatalogRestrictions() {
      return and();
    }
    
  
  }

}
